@@ -303,7 +303,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                         + 'mmButton';
                     this.addOwnedQxObject(mmButton, mmBtnId);
                 }
-                let action_code = function () {
+                let action = function () {
                     var that = this;
                     if (!button.isEnabled()) {
                         return;
@@ -462,7 +462,7 @@ qx.Class.define("callbackery.ui.plugin.Action", {
                     }
                 }; // action_code
                 // wrap action such that it executes only after the event loop is free again
-                var action = () => setTimeout(action_code.bind(this),0);
+                //var action = () => setTimeout(action_code.bind(this),0);
 
                 if (btCfg.defaultAction) {
                     this._defaultAction = action;
