@@ -151,30 +151,17 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                     return;
                 }
                 var control = form.getControl(s.key);
-                //let callbackExecuted;
                 var callback = function(e){
-                    //if (callbackExecuted) return;
-                    // make sure we only run this once for every event sequence
-                    // callbackExecuted = true;
-                    // setTimeout(function(){
-                    //     callbackExecuted = false;
-                    // },0);
                     if (this._reconfSelectBoxRunning > 0) return;
-                    // var data = e.getData();
-                    let data = null;
-                    if (control.getValue) {
-                        data = control.getValue();
-                        // try to make qx see that the value changed
-                        // after loosing focus
-                        // when running in safari on ios
-                        control.resetValue();
-                        control.setValue(data);
-                    }
+                    var data = e.getData();
                     // handle events from selectboxes
-                    else if (control.getSelection && qx.lang.Type.isArray(data)){
+                    if (control.getSelection && qx.lang.Type.isArray(data)){
                         if (data.length > 0 && data[0]['getModel']){
                             data = data[0].getModel();
                         }
+                        else {
+                            data = null;
+                        }
                     }
                     var required = control.getRequired();
                     if (required){
@@ -212,8 +199,7 @@ qx.Class.define("callbackery.ui.plugin.Form", {
                     control.getSelection().addListener("change", callback, this);
                 }
                 else {
-                    // control.addListener('changeValue',callback,this);
-                    control.addListener('blur',callback,this);
+                    control.addListener('changeValue',callback,this);
                 }
             },this);
         },
